package cn.cecep.talroad.mapper.effective;

import cn.cecep.talroad.domain.effective.PcNationalCityRankingOther;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import java.util.List;
import java.util.Date;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

@Mapper
public interface PcNationalCityRankingOtherMapper extends BaseMapper<PcNationalCityRankingOther> {
    int updateBatch(List<PcNationalCityRankingOther> list);

    int updateBatchSelective(List<PcNationalCityRankingOther> list);

    int batchInsert(@Param("list") List<PcNationalCityRankingOther> list);

    List<PcNationalCityRankingOther> selectDayRankData(@Param("currDay") String currDay);

    List<PcNationalCityRankingOther> selectMonthRankData(@Param("currDay") String lastMonthDate);

    List<PcNationalCityRankingOther> selectYearRankData(@Param("currDay")String lastYearDate);

    void updateBatchRank(@Param("list") List<PcNationalCityRankingOther> cityList);
}
